@@ -23,6 +23,7 @@ def get_source_verify(url, block):
         raise Exception("来源已不可用：{}".format(url))
     if source.get("block_id") != block.get("identification"):
         raise Exception("来源和对应block不匹配：{} - {}".format(url, block.get("identification")))
+    source["total_count"] = get_source_total(source)
     return source
 
 
@@ -65,15 +66,16 @@ def get_source_total(source):
     return col.count(where)
 
 
-def update_source_latest(source, latest_url, latest_count):
+def update_source_latest(source, latest_url):
     col = get_col("sources")
-    total_count = source.get("total_count", 0)
+    latest_count = source.get("total_count", 0)
+    total_count= get_source_total(source)
     where = {"_id": source["_id"]}
 
     json_obj = {
-        "latest_count": latest_count,
+        "latest_count": total_count - latest_count,
         "latest_end_at": datetime.datetime.now(),
-        "total_count": (total_count + latest_count)
+        "total_count": total_count
     }
 
     if latest_url:
